@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
-from __future__ import print_function
-
+import gi
+gi.require_version("Gdk", "3.0")
+gi.require_version("Gtk", "3.0")
 from gi.repository import GObject, Gdk, Gtk
 import os
 from gettext import gettext as _
@@ -27,9 +28,9 @@ class DialogAddSourcesList:
         self.sourceslist = sourceslist
         self.get_comparable = get_comparable
         self.file = self.format_uri(file)
-        
+
         setup_ui(self, os.path.join(datadir, "gtkbuilder", "dialog-add-sources-list.ui"), domain="software-properties")
-        
+
         self.dialog = self.dialog_add_sources_list
         self.label = self.label_sources
         self.treeview = self.treeview_sources
@@ -70,7 +71,7 @@ class DialogAddSourcesList:
                 self.new_sources.matcher.match(source)
             # sort the list
             self.new_sources.list.sort(key=self.get_comparable)
-            
+
             for source in self.new_sources.list:
                 if source.invalid or source.disabled:
                     continue
